import { defineStore } from "pinia";
import type { User } from "@/client";
import { UserService } from "@/client";
import { OpenAPI } from "@/client";

export type RootState = {
  token: string | null;
  user: User | null;
};

export const useAuthStore = defineStore({
  id: "auth",
  state: () =>
    ({
      token: null,
      user: null,
    } as RootState),
  getters: {
    authenticated: (state) => state.token != null,
  },
  actions: {
    setToken(token: string | null) {
      if (token != null) {
        OpenAPI.TOKEN = token;
        this.token = token;
        UserService.userGetLoggedInUser()
          .then((user) => {
            this.user = user;
          })
          .catch(() => {
            this.token = null;
          });
      } else {
        this.token = null;
        this.user = null;
      }
    },
    updateUser() {
      this.setToken(this.token);
    },
    logout() {
      this.setToken(null);
    },
  },
});
